@@ -3,9 +3,10 @@ from typing import Any, Dict, List, Union
 
 from ..users.projector import get_user_name
 from ..utils.projector import (
-    AllData,
+    ProjectorAllDataProvider,
     ProjectorElementException,
     get_config,
+    get_model,
     register_projector_slide,
 )
 
@@ -15,20 +16,24 @@ from ..utils.projector import (
 #            side effects.
 
 
-async def get_sorted_agenda_items(all_data: AllData) -> List[Dict[str, Any]]:
+async def get_sorted_agenda_items(
+    agenda_items: Dict[int, Dict[str, Any]]
+) -> List[Dict[str, Any]]:
     """
     Returns all sorted agenda items by id first and then weight, resulting in
     ordered items, if some have the same weight.
     """
     return sorted(
-        sorted(all_data["agenda/item"].values(), key=lambda item: item["id"]),
+        sorted(agenda_items.values(), key=lambda item: item["id"]),
         key=lambda item: item["weight"],
     )
 
 
-async def get_flat_tree(all_data: AllData, parent_id: int = 0) -> List[Dict[str, Any]]:
+async def get_flat_tree(
+    agenda_items: Dict[int, Dict[str, Any]], parent_id: int = 0
+) -> List[Dict[str, Any]]:
     """
-    Build the item tree from all_data.
+    Build the item tree from all_data_provider.
 
     Only build the tree from elements unterneath parent_id.
 
@@ -38,16 +43,16 @@ async def get_flat_tree(all_data: AllData, parent_id: int = 0) -> List[Dict[str,
 
     # Build a dict from an item_id to all its children
     children: Dict[int, List[int]] = defaultdict(list)
-    if "agenda/item" in all_data:
-        for item in await get_sorted_agenda_items(all_data):
-            if item["type"] == 1:  # only normal items
-                children[item["parent_id"] or 0].append(item["id"])
+
+    for item in await get_sorted_agenda_items(agenda_items):
+        if item["type"] == 1:  # only normal items
+            children[item["parent_id"] or 0].append(item["id"])
 
     tree = []
 
-    async def get_children(item_ids: List[int], depth: int) -> None:
+    def build_tree(item_ids: List[int], depth: int) -> None:
         for item_id in item_ids:
-            item = all_data["agenda/item"][item_id]
+            item = agenda_items[item_id]
             title_information = item["title_information"]
             title_information["_agenda_item_number"] = item["item_number"]
             tree.append(
@@ -57,25 +62,29 @@ async def get_flat_tree(all_data: AllData, parent_id: int = 0) -> List[Dict[str,
                     "depth": depth,
                 }
             )
-            await get_children(children[item_id], depth + 1)
+            build_tree(children[item_id], depth + 1)
 
-    await get_children(children[parent_id], 0)
+    build_tree(children[parent_id], 0)
     return tree
 
 
 async def item_list_slide(
-    all_data: AllData, element: Dict[str, Any], projector_id: int
+    all_data_provider: ProjectorAllDataProvider,
+    element: Dict[str, Any],
+    projector_id: int,
 ) -> Dict[str, Any]:
     """
     Item list slide.
 
     Returns all root items or all children of an item.
     """
-    only_main_items = element.get("only_main_items", True)
+    # fetch all items, so they are cached:
+    all_agenda_items = await all_data_provider.get_collection("agenda/item")
 
+    only_main_items = element.get("only_main_items", True)
     if only_main_items:
         agenda_items = []
-        for item in await get_sorted_agenda_items(all_data):
+        for item in await get_sorted_agenda_items(all_agenda_items):
             if item["parent_id"] is None and item["type"] == 1:
                 title_information = item["title_information"]
                 title_information["_agenda_item_number"] = item["item_number"]
@@ -86,13 +95,15 @@ async def item_list_slide(
                     }
                 )
     else:
-        agenda_items = await get_flat_tree(all_data)
+        agenda_items = await get_flat_tree(all_agenda_items)
 
     return {"items": agenda_items}
 
 
 async def list_of_speakers_slide(
-    all_data: AllData, element: Dict[str, Any], projector_id: int
+    all_data_provider: ProjectorAllDataProvider,
+    element: Dict[str, Any],
+    projector_id: int,
 ) -> Dict[str, Any]:
     """
     List of speakers slide.
@@ -104,35 +115,35 @@ async def list_of_speakers_slide(
     if list_of_speakers_id is None:
         raise ProjectorElementException("id is required for list of speakers slide")
 
-    return await get_list_of_speakers_slide_data(all_data, list_of_speakers_id)
+    return await get_list_of_speakers_slide_data(all_data_provider, list_of_speakers_id)
 
 
 async def get_list_of_speakers_slide_data(
-    all_data: AllData, list_of_speakers_id: int
+    all_data_provider: ProjectorAllDataProvider, list_of_speakers_id: int
 ) -> Dict[str, Any]:
-    try:
-        list_of_speakers = all_data["agenda/list-of-speakers"][list_of_speakers_id]
-    except KeyError:
-        raise ProjectorElementException(
-            f"List of speakers {list_of_speakers_id} does not exist"
-        )
+    list_of_speakers = await get_model(
+        all_data_provider, "agenda/list-of-speakers", list_of_speakers_id
+    )
 
     title_information = list_of_speakers["title_information"]
     # try to get the agenda item for the content object (which must not exist)
-    agenda_item_id = all_data[list_of_speakers["content_object"]["collection"]][
-        list_of_speakers["content_object"]["id"]
-    ].get("agenda_item_id")
-    if agenda_item_id:
-        title_information["_agenda_item_number"] = all_data["agenda/item"][
-            agenda_item_id
-        ]["item_number"]
+    content_object = await get_model(
+        all_data_provider,
+        list_of_speakers["content_object"]["collection"],
+        list_of_speakers["content_object"]["id"],
+    )
+    agenda_item_id = content_object.get("agenda_item_id")
+    if agenda_item_id is not None:
+        agenda_item = await all_data_provider.get("agenda/item", agenda_item_id)
+        if agenda_item is not None:
+            title_information["_agenda_item_number"] = agenda_item["item_number"]
 
     # Partition speaker objects to waiting, current and finished
     speakers_waiting = []
     speakers_finished = []
     current_speaker = None
     for speaker in list_of_speakers["speakers"]:
-        user = await get_user_name(all_data, speaker["user_id"])
+        user = await get_user_name(all_data_provider, speaker["user_id"])
         formatted_speaker = {
             "user": user,
             "marked": speaker["marked"],
@@ -151,8 +162,12 @@ async def get_list_of_speakers_slide_data(
     speakers_waiting = sorted(speakers_waiting, key=lambda s: s["weight"])
     speakers_finished = sorted(speakers_finished, key=lambda s: s["end_time"])
 
-    number_of_last_speakers = await get_config(all_data, "agenda_show_last_speakers")
-    number_of_next_speakers = await get_config(all_data, "agenda_show_next_speakers")
+    number_of_last_speakers = await get_config(
+        all_data_provider, "agenda_show_last_speakers"
+    )
+    number_of_next_speakers = await get_config(
+        all_data_provider, "agenda_show_next_speakers"
+    )
 
     if number_of_last_speakers == 0:
         speakers_finished = []
@@ -174,7 +189,7 @@ async def get_list_of_speakers_slide_data(
 
 
 async def get_current_list_of_speakers_id_for_projector(
-    all_data: AllData, projector: Dict[str, Any]
+    all_data_provider: ProjectorAllDataProvider, projector: Dict[str, Any]
 ) -> Union[int, None]:
     """
     Search for elements, that do have a list of speakers:
@@ -189,94 +204,88 @@ async def get_current_list_of_speakers_id_for_projector(
             continue
         collection = element["name"]
         id = element["id"]
-        if collection not in all_data or id not in all_data[collection]:
+        model = await all_data_provider.get(collection, id)
+        if model is None:
             continue
 
-        model = all_data[collection][id]
         if "list_of_speakers_id" not in model:
             continue
 
-        if not model["list_of_speakers_id"] in all_data["agenda/list-of-speakers"]:
+        list_of_speakers_id = model["list_of_speakers_id"]
+        los_exists = await all_data_provider.exists(
+            "agenda/list-of-speakers", list_of_speakers_id
+        )
+        if not los_exists:
             continue
 
-        list_of_speakers_id = model["list_of_speakers_id"]
         break
 
     return list_of_speakers_id
 
 
 async def get_reference_projector(
-    all_data: AllData, projector_id: int
+    all_data_provider: ProjectorAllDataProvider, projector_id: int
 ) -> Dict[str, Any]:
     """
     Returns the reference projector to the given projector (by id)
     """
-    try:
-        this_projector = all_data["core/projector"][projector_id]
-    except KeyError:
-        raise ProjectorElementException(f"Projector {projector_id} does not exist")
+    this_projector = await get_model(all_data_provider, "core/projector", projector_id)
 
     reference_projector_id = this_projector["reference_projector_id"] or projector_id
-    try:
-        reference_projector = all_data["core/projector"][reference_projector_id]
-    except KeyError:
-        raise ProjectorElementException(
-            f"Projector {reference_projector_id} does not exist"
-        )
-
-    return reference_projector
+    return await get_model(all_data_provider, "core/projector", reference_projector_id)
 
 
 async def current_list_of_speakers_slide(
-    all_data: AllData, element: Dict[str, Any], projector_id: int
+    all_data_provider: ProjectorAllDataProvider,
+    element: Dict[str, Any],
+    projector_id: int,
 ) -> Dict[str, Any]:
     """
     The current list of speakers slide. Creates the data for the given projector.
     """
-    reference_projector = await get_reference_projector(all_data, projector_id)
+    reference_projector = await get_reference_projector(all_data_provider, projector_id)
     list_of_speakers_id = await get_current_list_of_speakers_id_for_projector(
-        all_data, reference_projector
+        all_data_provider, reference_projector
     )
     if list_of_speakers_id is None:  # no element found
         return {}
 
-    return await get_list_of_speakers_slide_data(all_data, list_of_speakers_id)
+    return await get_list_of_speakers_slide_data(all_data_provider, list_of_speakers_id)
 
 
 async def current_speaker_chyron_slide(
-    all_data: AllData, element: Dict[str, Any], projector_id: int
+    all_data_provider: ProjectorAllDataProvider,
+    element: Dict[str, Any],
+    projector_id: int,
 ) -> Dict[str, Any]:
     """
     Returns the username for the current speaker.
     """
     # get projector for color information
-    projector = all_data["core/projector"][projector_id]
+    projector = await get_model(all_data_provider, "core/projector", projector_id)
 
     slide_data = {
         "background_color": projector["chyron_background_color"],
         "font_color": projector["chyron_font_color"],
     }
 
-    reference_projector = await get_reference_projector(all_data, projector_id)
+    reference_projector = await get_reference_projector(all_data_provider, projector_id)
     list_of_speakers_id = await get_current_list_of_speakers_id_for_projector(
-        all_data, reference_projector
+        all_data_provider, reference_projector
     )
     if list_of_speakers_id is None:  # no element found
         return slide_data
 
     # get list of speakers to search current speaker
-    try:
-        list_of_speakers = all_data["agenda/list-of-speakers"][list_of_speakers_id]
-    except KeyError:
-        raise ProjectorElementException(
-            f"List of speakers {list_of_speakers_id} does not exist"
-        )
+    list_of_speakers = await get_model(
+        all_data_provider, "agenda/list-of-speakers", list_of_speakers_id
+    )
 
     # find current speaker
     current_speaker = None
     for speaker in list_of_speakers["speakers"]:
         if speaker["begin_time"] is not None and speaker["end_time"] is None:
-            current_speaker = await get_user_name(all_data, speaker["user_id"])
+            current_speaker = await get_user_name(all_data_provider, speaker["user_id"])
             break
 
     if current_speaker is not None:
