@@ -15,9 +15,12 @@ class CoreAppConfig(AppConfig):
 
     def ready(self):
         # Import all required stuff.
+        # Let all client websocket message register
+        from ..utils import websocket_client_messages  # noqa
+        from ..utils.rest_api import router
+        from . import serializers  # noqa
         from .config import config
         from .projector import register_projector_slides
-        from . import serializers  # noqa
         from .signals import (
             autoupdate_for_many_to_many_relations,
             cleanup_unused_permissions,
@@ -29,21 +32,11 @@ class CoreAppConfig(AppConfig):
         from .views import (
             ConfigViewSet,
             CountdownViewSet,
+            ProjectionDefaultViewSet,
             ProjectorMessageViewSet,
             ProjectorViewSet,
-            ProjectionDefaultViewSet,
             TagViewSet,
         )
-        from .websocket import (
-            NotifyWebsocketClientMessage,
-            ConstantsWebsocketClientMessage,
-            GetElementsWebsocketClientMessage,
-            AutoupdateWebsocketClientMessage,
-            ListenToProjectors,
-            PingPong,
-        )
-        from ..utils.rest_api import router
-        from ..utils.websocket import register_client_message
 
         # Collect all config variables before getting the constants.
         config.collect_config_variables_from_apps()
@@ -92,23 +85,15 @@ class CoreAppConfig(AppConfig):
             self.get_model("Countdown").get_collection_string(), CountdownViewSet
         )
 
-        # Register client messages
-        register_client_message(NotifyWebsocketClientMessage())
-        register_client_message(ConstantsWebsocketClientMessage())
-        register_client_message(GetElementsWebsocketClientMessage())
-        register_client_message(AutoupdateWebsocketClientMessage())
-        register_client_message(ListenToProjectors())
-        register_client_message(PingPong())
-
         if "runserver" in sys.argv or "changeconfig" in sys.argv:
             from openslides.utils.startup import run_startup_hooks
 
             run_startup_hooks()
 
     def get_startup_hooks(self):
-        from openslides.utils.constants import set_constants_from_apps
-        from openslides.utils.cache import element_cache
         from openslides.core.models import History
+        from openslides.utils.cache import element_cache
+        from openslides.utils.constants import set_constants_from_apps
 
         return {
             10: element_cache.ensure_schema_version,
@@ -144,6 +129,10 @@ class CoreAppConfig(AppConfig):
             "PRIORITIZED_GROUP_IDS",
             "PING_INTERVAL",
             "PING_TIMEOUT",
+            "ENABLE_ELECTRONIC_VOTING",
+            "JITSI_DOMAIN",
+            "JITSI_ROOM_NAME",
+            "JITSI_ROOM_PASSWORD",
         ]
         client_settings_dict = {}
         for key in client_settings_keys:
