@@ -1,13 +1,17 @@
+from typing import Iterable
+
 from asgiref.sync import async_to_sync
 from django.conf import settings
 from django.db import models, transaction
 from django.utils.timezone import now
 from jsonfield import JSONField
 
-from ..utils.autoupdate import Element
-from ..utils.cache import element_cache, get_element_id
-from ..utils.locking import locking
-from ..utils.models import SET_NULL_AND_AUTOUPDATE, RESTModelMixin
+from openslides.utils.autoupdate import AutoupdateElement
+from openslides.utils.cache import element_cache, get_element_id
+from openslides.utils.locking import locking
+from openslides.utils.manager import BaseManager
+from openslides.utils.models import SET_NULL_AND_AUTOUPDATE, RESTModelMixin
+
 from .access_permissions import (
     ConfigAccessPermissions,
     CountdownAccessPermissions,
@@ -18,17 +22,21 @@ from .access_permissions import (
 )
 
 
-class ProjectorManager(models.Manager):
+class ProjectorManager(BaseManager):
     """
-    Customized model manager to support our get_full_queryset method.
+    Customized model manager to support our get_prefetched_queryset method.
     """
 
-    def get_full_queryset(self):
+    def get_prefetched_queryset(self, *args, **kwargs):
         """
         Returns the normal queryset with all projectors. In the background
         projector defaults are prefetched from the database.
         """
-        return self.get_queryset().prefetch_related("projectiondefaults")
+        return (
+            super()
+            .get_prefetched_queryset(*args, **kwargs)
+            .prefetch_related("projectiondefaults")
+        )
 
 
 class Projector(RESTModelMixin, models.Model):
@@ -75,7 +83,7 @@ class Projector(RESTModelMixin, models.Model):
     scale = models.IntegerField(default=0)
     scroll = models.IntegerField(default=0)
 
-    width = models.PositiveIntegerField(default=1024)
+    width = models.PositiveIntegerField(default=1200)
     aspect_ratio_numerator = models.PositiveIntegerField(default=16)
     aspect_ratio_denominator = models.PositiveIntegerField(default=9)
 
@@ -110,6 +118,7 @@ class Projector(RESTModelMixin, models.Model):
             ("can_see_projector", "Can see the projector"),
             ("can_manage_projector", "Can manage the projector"),
             ("can_see_frontpage", "Can see the front page"),
+            ("can_see_livestream", "Can see the live stream"),
         )
 
 
@@ -249,12 +258,12 @@ class HistoryData(models.Model):
         default_permissions = ()
 
 
-class HistoryManager(models.Manager):
+class HistoryManager(BaseManager):
     """
     Customized model manager for the history model.
     """
 
-    def add_elements(self, elements):
+    def add_elements(self, elements: Iterable[AutoupdateElement]):
         """
         Method to add elements to the history. This does not trigger autoupdate.
         """
@@ -266,14 +275,13 @@ class HistoryManager(models.Manager):
                     # Do not update history if history is disabled.
                     continue
                 # HistoryData is not a root rest element so there is no autoupdate and not history saving here.
-                data = HistoryData.objects.create(full_data=element["full_data"])
+                data = HistoryData.objects.create(full_data=element.get("full_data"))
                 instance = self.model(
                     element_id=get_element_id(
                         element["collection_string"], element["id"]
                     ),
                     now=history_time,
                     information=element.get("information", []),
-                    restricted=element.get("restricted", False),
                     user_id=element.get("user_id"),
                     full_data=data,
                 )
@@ -297,7 +305,7 @@ class HistoryManager(models.Manager):
                     for collection_string, data in all_full_data.items():
                         for full_data in data:
                             elements.append(
-                                Element(
+                                AutoupdateElement(
                                     id=full_data["id"],
                                     collection_string=collection_string,
                                     full_data=full_data,
@@ -324,8 +332,6 @@ class History(models.Model):
 
     information = JSONField()
 
-    restricted = models.BooleanField(default=False)
-
     user = models.ForeignKey(
         settings.AUTH_USER_MODEL, null=True, on_delete=models.SET_NULL
     )
