@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.1.4 (2019-12-11)
+ * Version: 5.2.2 (2020-04-23)
  */
 (function (domGlobals) {
     'use strict';
@@ -275,6 +275,19 @@
       editor.insertContent(ch);
     };
 
+    var __assign = function () {
+      __assign = Object.assign || function __assign(t) {
+        for (var s, i = 1, n = arguments.length; i < n; i++) {
+          s = arguments[i];
+          for (var p in s)
+            if (Object.prototype.hasOwnProperty.call(s, p))
+              t[p] = s[p];
+        }
+        return t;
+      };
+      return __assign.apply(this, arguments);
+    };
+
     var hasOwnProperty = Object.prototype.hasOwnProperty;
     var shallow = function (old, nu) {
       return nu;
@@ -372,7 +385,7 @@
     var getUserDefinedEmoticons = function (editor) {
       var userDefinedEmoticons = Settings.getAppendedEmoticons(editor);
       return map$1(userDefinedEmoticons, function (value) {
-        return merge({
+        return __assign({
           keywords: [],
           category: 'user'
         }, value);
