@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.1.4 (2019-12-11)
+ * Version: 5.2.2 (2020-04-23)
  */
 (function (domGlobals) {
     'use strict';
@@ -482,6 +482,7 @@
     var osx = 'OSX';
     var solaris = 'Solaris';
     var freebsd = 'FreeBSD';
+    var chromeos = 'ChromeOS';
     var isOS = function (name, current) {
       return function () {
         return current === name;
@@ -505,7 +506,8 @@
         isOSX: isOS(osx, current),
         isLinux: isOS(linux, current),
         isSolaris: isOS(solaris, current),
-        isFreeBSD: isOS(freebsd, current)
+        isFreeBSD: isOS(freebsd, current),
+        isChromeOS: isOS(chromeos, current)
       };
     };
     var OperatingSystem = {
@@ -517,7 +519,8 @@
       linux: constant(linux),
       osx: constant(osx),
       solaris: constant(solaris),
-      freebsd: constant(freebsd)
+      freebsd: constant(freebsd),
+      chromeos: constant(chromeos)
     };
 
     var DeviceType = function (os, browser, userAgent, mediaMatch) {
@@ -657,8 +660,8 @@
       },
       {
         name: 'OSX',
-        search: checkContains('os x'),
-        versionRegexes: [/.*?os\ x\ ?([0-9]+)_([0-9]+).*/]
+        search: checkContains('mac os x'),
+        versionRegexes: [/.*?mac\ os\ x\ ?([0-9]+)_([0-9]+).*/]
       },
       {
         name: 'Linux',
@@ -674,6 +677,11 @@
         name: 'FreeBSD',
         search: checkContains('freebsd'),
         versionRegexes: []
+      },
+      {
+        name: 'ChromeOS',
+        search: checkContains('cros'),
+        versionRegexes: [/.*?chrome\/([0-9]+)\.([0-9]+).*/]
       }
     ];
     var PlatformInfo = {
@@ -798,9 +806,13 @@
     var getInsertToolbarItems = function (editor) {
       return EditorSettings.getToolbarItemsOr(editor, 'quickbars_insert_toolbar', 'quickimage quicktable');
     };
+    var getImageToolbarItems = function (editor) {
+      return EditorSettings.getToolbarItemsOr(editor, 'quickbars_image_toolbar', 'alignleft aligncenter alignright');
+    };
     var Settings = {
       getTextSelectionToolbarItems: getTextSelectionToolbarItems,
-      getInsertToolbarItems: getInsertToolbarItems
+      getInsertToolbarItems: getInsertToolbarItems,
+      getImageToolbarItems: getImageToolbarItems
     };
 
     var addToEditor = function (editor) {
@@ -830,21 +842,29 @@
     var InsertToolbars = { addToEditor: addToEditor };
 
     var addToEditor$1 = function (editor) {
-      editor.ui.registry.addContextToolbar('imageselection', {
-        predicate: function (node) {
-          return node.nodeName === 'IMG' || node.nodeName === 'FIGURE' && /image/i.test(node.className);
-        },
-        items: 'alignleft aligncenter alignright',
-        position: 'node'
-      });
+      var isEditable = function (node) {
+        return editor.dom.getContentEditableParent(node) !== 'false';
+      };
+      var isImage = function (node) {
+        return node.nodeName === 'IMG' || node.nodeName === 'FIGURE' && /image/i.test(node.className);
+      };
+      var imageToolbarItems = Settings.getImageToolbarItems(editor);
+      if (imageToolbarItems.trim().length > 0) {
+        editor.ui.registry.addContextToolbar('imageselection', {
+          predicate: isImage,
+          items: imageToolbarItems,
+          position: 'node'
+        });
+      }
       var textToolbarItems = Settings.getTextSelectionToolbarItems(editor);
       if (textToolbarItems.trim().length > 0) {
         editor.ui.registry.addContextToolbar('textselection', {
           predicate: function (node) {
-            return !editor.selection.isCollapsed();
+            return !isImage(node) && !editor.selection.isCollapsed() && isEditable(node);
           },
           items: textToolbarItems,
-          position: 'selection'
+          position: 'selection',
+          scope: 'editor'
         });
       }
     };
